@@ -3,6 +3,7 @@ import fnmatch
 import os
 import py_compile
 from os.path import join as _j
+from typing import List
 
 from django.conf import settings
 from django.core.management.base import BaseCommand, CommandError
@@ -12,7 +13,7 @@ from django_extensions.management.utils import signalcommand
 
 class Command(BaseCommand):
     help = "Compile python bytecode files for the project."
-    requires_system_checks = False
+    requires_system_checks: List[str] = []
 
     def add_arguments(self, parser):
         parser.add_argument('--path', '-p', action='store', dest='path',
@@ -20,11 +21,11 @@ class Command(BaseCommand):
 
     @signalcommand
     def handle(self, *args, **options):
-        project_root = options.get("path", None)
+        project_root = options["path"]
         if not project_root:
             project_root = getattr(settings, 'BASE_DIR', None)
 
-        verbosity = int(options.get("verbosity"))
+        verbosity = options["verbosity"]
         if not project_root:
             raise CommandError("No --path specified and settings.py does not contain BASE_DIR")
 
