@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 import inspect
 import os
+import re
+
 
 from django.apps import apps
 from django.core.management import color
 from django.core.management import BaseCommand
 from django.utils import termcolors
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_str
 
 from django_extensions.compat import load_tag_library
 from django_extensions.management.color import _dummy_style_func
@@ -30,17 +32,16 @@ def color_style():
 
 
 def format_block(block, nlspaces=0):
-    """Format the given block of text, trimming leading/trailing
+    """
+    Format the given block of text, trimming leading/trailing
     empty lines and any leading whitespace that is common to all lines.
     The purpose is to let us list a code block as a multiline,
     triple-quoted Python string, taking care of
     indentation concerns.
-    http://code.activestate.com/recipes/145672/"""
-
-    import re
-
+    http://code.activestate.com/recipes/145672/
+    """
     # separate block into lines
-    lines = smart_text(block).split('\n')
+    lines = smart_str(block).split('\n')
 
     # remove leading/trailing empty lines
     while lines and not lines[0]:
